# xfs:       Starts the X Font Server
#
# Version:      @(#) /etc/init.d/xfs 2.0
#
# description: Starts and stops the X Font Server at boot time and shutdown. \
#              It also takes care of (re-)generating font lists.

daemon daemon/xfs {
	need = system/initial system/mountfs system/bootmisc
	daemon {
   umask 133
   FC_CACHE=/usr/bin/fc-cache

   # chkfontpath output filtering, strips all of the junk output by
   # chkfontpath that we do not want, including headers, FPE numbers and
   # whitespace and other junk.  Also filters out FPE's with trailing
   # modifiers such as ":unscaled" et al.
   for dir in $(/usr/sbin/chkfontpath --list | sed -e '/^Current/d;s#^[0-9]*: ##g;s#^/.*:[a-z]*$##g;/^[[:space:]]*$/d' | sort | uniq) ;do
      if [ -d "$dir" ]; then
         cd "$dir"
         # If fonts.dir does not exist, or if there are files in the
         # directory with a newer change time, regenerate fonts.dir, etc.
         # Using "-cnewer" here fixes bug #53737
         if [ ! -e fonts.dir ] || [ -n "$(/usr/bin/find . -maxdepth 1 -type f -cnewer fonts.dir -not -name 'fonts.cache*')" ]; then
            /bin/rm -f fonts.dir
            if /bin/ls | /bin/grep -iqs '\.ot[cf]$' ; then
               # Opentype fonts found, generate fonts.scale and fonts.dir
               /usr/sbin/mkfontscale . && /usr/sbin/mkfontdir . &>/dev/null
            elif /bin/ls | /bin/grep -iqs '\.tt[cf]$' ; then
               # TrueType fonts found, generate fonts.scale and fonts.dir
               /usr/sbin/ttmkfdir -d . -o fonts.scale && /usr/sbin/mkfontdir . &>/dev/null
            elif /bin/ls | /bin/grep -Eiqsv '(^fonts\.(scale|alias|cache.*)$|.+(\.[ot]t[cf]|dir)$)' ; then
               # This directory contains non-TrueType/non-Opentype fonts
               /usr/sbin/mkfontdir . &>/dev/null
            fi
         fi
      fi
   done
   # Now we run fc-cache, assuming fonts may have been added, without
   # explicitly checking, as it is rather fast anyway.  Some older versions
   # of fc-cache will SEGV, which is prevented by invoking it with HOME=/
   [ -x "$FC_CACHE" ] && HOME=/ "$FC_CACHE"

   FONT_UNIX_DIR=/tmp/.font-unix
   # Clean out .font-unix dir, and recreate it with the proper ownership and
   # permissions.
   /bin/rm -rf $FONT_UNIX_DIR
   /bin/mkdir $FONT_UNIX_DIR
   /bin/chown root:root $FONT_UNIX_DIR
   /bin/chmod 1777 $FONT_UNIX_DIR
    
   exec /usr/X11R6/bin/xfs -droppriv -nodaemon
}
}

