service system/mountroot {
	need = system/initial
	critical
start {
	retval=0

	# startDM
	if [ -f /sbin/dmsetup ]; then
	    /sbin/dmsetup mknodes >/dev/null 2>&1 
	fi
	
	#startLVM
	if [ -f /usr/sbin/vgchange ]; then
	    # try to load module in case that hasn't been done yet
	    /sbin/modprobe lvm >/dev/null 2>&1
	    /sbin/modprobe lvm-mod >/dev/null 2>&1
	    /sbin/modprobe dm-mod >/dev/null 2>&1
	    /bin/mknod --mode=600 /dev/lvm c 109 0 >/dev/null 2>&1 || true
	    dm_dir="/dev/mapper"
	    dm_file="$dm_dir/control"
	    if [ ! -f /dev/.devfsd ]; then
		major=$(/bin/grep "[0-9] misc$" /proc/devices | sed 's/[ ]\+misc//')
		minor=$(/bin/grep "[0-9] device-mapper$" /proc/misc | sed 's/[ ]\+device-mapper//')
		test -d $dm_dir || /bin/mkdir --mode=755 $dm_dir >/dev/null 2>&1
		test -c $dm_file -o -z "$major" -o -z "$minor" || /bin/mknod --mode=600 $dm_file c $major $minor >/dev/null 2>&1
	    fi
	    /usr/sbin/vgscan --ignorelockingfailure --mknodes >/dev/null 2>&1
	    /usr/sbin/vgchange --ignorelockingfailure -a y >/dev/null 2>&1
	fi
	
	# startEVMS
	if [ -f /sbin/evms_activate ]; then
	    /sbin/evms_activate >/dev/null 2>&1 
	fi
		
	# checkROOT
	if [ ! -f /fastboot ] ; then
	    /bin/echo "Remounting root filesystem read-only (if necessary) ..."
	    /bin/mount -n -o remount,ro / >/dev/null 2>&1 

	    if [ -f /forcefsck ] ; then
		/bin/echo "Checking root filesystem (full fsck forced)"
		/sbin/fsck -C -a -f /
		# /forcefsck isn't deleted because system/mountfs need it.
		# it'll be deleted in that script.
		retval=$?
	    else

		# Obey the fs_passno setting for / (see fstab(5))
		# - find the / entry
		# - make sure we have 6 fields
		# - see if fs_passno is something other than 0
		ROOTLINE=$(cat /etc/fstab | while read fs mountpoint typ options dump pass junk ; do if [ "${fs}" = "/*" ]; then if [ "${mountpoint}" == "/" ] ; then if [ "${pass}" != "0" ] ; then /bin/echo ${fs} ${mountpoint} ${typ} ${options} ${dump} ${pass} ; fi ; fi; fi done) # */
		if [ -n "$ROOTLINE" ]; then
		    /bin/echo "Checking root filesystem ..."
		    /sbin/fsck -C -T -a /
		    retval=$?
		else
		    /bin/echo "Skipping root filesystem check (fstab's passno == 0) ..."
		    retval=0
		fi
		
	    fi
	    
	    if [ "${retval}" -eq 0 ] ; then
		/bin/echo "Filesystem check on / succeeded, now mounting ..."
	    elif [ "${retval}" -eq 1 ] ; then
		/bin/echo "Filesystem repaired, now mounting ..."
	    elif [ "${retval}" -eq 2 ] || [ "${retval}" -eq 3 ] ; then
		/bin/echo "Filesystem repaired, but reboot needed!"
		/bin/echo -ne "\a"; sleep 1; /bin/echo -ne "\a"; sleep 1
		/bin/echo -ne "\a"; sleep 1; /bin/echo -ne "\a"; sleep 1
		/bin/echo "Rebooting in 2 seconds ..."
		/bin/sleep 2
		/bin/echo "Rebooting"
		/sbin/ngc -j reboot
	    else
		/bin/echo "Filesystem couldn't be fixed :("
		#exit 1, with critical set, will shut down initng, and execute sulogin.
		exit 1
	    fi
	fi
	/bin/echo "Should mount / now."

	# Should we mount root rw ?
	if /bin/mount -vf -o remount / | /bin/grep "\(.*rw.*\)" 2>&1 >/dev/null
	then

	    /bin/echo "Remounting root filesystem read/write"
	    /bin/mount -n -o remount,rw / >/dev/null 2>&1 
	    if [ "$?" -ne 0 ]
	    then
		/bin/echo "Root filesystem could not be mounted read/write :("
		exit 1
	    fi
	fi

	#
	# Create /etc/mtab
	#
	# Don't create mtab if /etc is readonly
	if ! /usr/bin/touch /etc/mtab 2>/dev/null
	then
		/bin/echo "Skipping /etc/mtab initialization (ro root?)"
		exit 0
	fi

	# Clear the existing mtab
	>/etc/mtab

	# Add the entry for / to mtab
	/bin/mount -f /

	# Don't list root more than once
	/bin/grep -v " / " /proc/mounts >>/etc/mtab
	# Now make sure /etc/mtab have additional info (gid, etc) in there

	/bin/cat /proc/mounts | while read pm_fs pm_mountpoint pm_junk ; do
	  /bin/cat /etc/fstab | while read ef_fs ef_mountpoint ef_junk ; do
	    if [ "${pm_mountpoint}" = "${ef_mountpoint}" ] ; then
	      /bin/echo "Mounting ${pm_mountpoint} rw ..."
              /bin/mount -f -o remount "${pm_mountpoint}"
              continue
            fi
          done
        done

	# Remove stale backups
	/bin/rm -f /etc/mtab~ /etc/mtab~~ &> /dev/null
	# Return Happily., or sulogin will be executed.
	exit 0
}

# Someday, it shud also cleanup.
#stop {
#    #Unmount root fs ro.
#    mount -n -o remount,ro /
#}

}
